/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package com.service.customer.web;

import com.service.customer.ejb.Customer;
import com.service.customer.ejb.ProcessCustomerSessionLocal;

import java.util.Locale;
import java.util.ResourceBundle;
import java.util.List;
import javax.naming.InitialContext;


public class CustomerServiceJavaBean
{
   private ProcessCustomerSessionLocal process = null;
   private ResourceBundle      bundle = null;
   private String              JNDI_PROCESS_EJB = null;

   private String      action = "";
   private String      customerID = "";
   private String      fullName = "";
   private String      emailAddress = "";
   private String      interests = "";


   public CustomerServiceJavaBean()
   {
      InitialContext initial = null;

      bundle = ResourceBundle.getBundle("customer", Locale.getDefault(), CustomerServiceJavaBean.class.getClassLoader());
      JNDI_PROCESS_EJB = bundle.getString("jndi.process.ejb");

      try
      {
         initial = new InitialContext();
		 process = (ProcessCustomerSessionLocal) initial.lookup(JNDI_PROCESS_EJB.trim());
         System.out.println("Successful looking up: '" + JNDI_PROCESS_EJB.trim() + "'");
      } // end try

      catch (Exception e)
      {
         e.printStackTrace();
      } // end catch
   } // end CustomerServiceJavaBean


   public List<Customer> getAllCustomers()
   {
      List<Customer> customerList = null;

      try
      {
         customerList = process.findAllCustomers();
      } // end try

      catch (Exception e)
      {
         customerList = null;
         e.printStackTrace();
      } // end catch

      return customerList;
   } // end getAllCustomerss
} // end CustomerServiceJavaBean
